Learn R Programming

genesysr (version 2.2.0)

get_accessions: Get accession passport data as a data table.

Description

Get accession passport data as a data table.

Usage

get_accessions(filters = NULL, fields = SELECT_INFO_FIELDS)

Value

Data table

Arguments

filters

an R structure with Genesys filters

fields

list of fields to fetch from Genesys. See examples. The following constants are also available SELECT_INFO_FIELDS, SELECT_GEO_FIELDS and SELECT_INFO_FIELDS (default).

See Also

mcpd_filter

Examples

Run this code
if (FALSE) {
  # Retrieve all accession data by country of origin (Slovenia, Ivory Coast)
  accessions <- genesysr::get_accessions(list(countryOfOrigin = list(code3 = list("SVN", "CIV"))))

  # Focus on geolocation data
  musa <- genesysr::get_accessions(
    list(taxonomy = list(genus = list("Musa"))),
    select = genesysr::SELECT_GEO_FIELDS
  )

  # Fetch only accession number and coordinates of Musa accessions
  musa <- genesysr::get_accessions(
    list(taxonomy = list(genus = list("Musa"))),
    fields = c("ACCENUMB", "DECLATITUDE", "DECLONGITUDE")
  )
}

Run the code above in your browser using DataLab