The authorization URL will open in a browser, ask the user to grant permissions to R. After successful authentication the browser will display a message:
user_login(redirect_uri = "http://127.0.0.1:48913")a custom redirect_uri to submit as part of the authentication request. This is most useful if the default port is blocked and you wish to specify another port: redirect_uri = "http://127.0.0.1:44211" Note that "http://127.0.0.1" is requred and that "http://localhost" will not work.
``` Authentication complete. Please close this page and return to R. ```
Close the browser and return to R.
setup