Learn R Programming

genesysr (version 0.9.2)

user_login: Login to Genesys as a user

Description

The authorization URL will open in a browser, ask the user to grant permissions to R and the verification code must be copy-pasted after you grant access to the client.

Usage

user_login()

Arguments

See Also

setup